@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: descriptive
 version: 0.9.4
-id: descriptive-0.9.4-a5d8b9583a1589652bfd0d3b2a4beca1
-key: descr_HtIbBO1ognBHqvv0f1DIZW
+id: descriptive-0.9.4-70384d36be22a818694ea91dfeb98f75
+key: descr_KdEHYPemVGD7aR8kMkJs8y
 license: BSD3
 copyright: 2015 Chris Done
 maintainer: chrisdone@gmail.com
@@ -23,11 +23,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/descriptive-0.9.4
-hs-libraries: HSdescriptive-0.9.4-HtIbBO1ognBHqvv0f1DIZW
+hs-libraries: HSdescriptive-0.9.4-KdEHYPemVGD7aR8kMkJs8y
 depends:
-    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
+    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    bifunctors-5.2.1-773112418cac918e191cb2ad7385e9ee
+    bifunctors-5.2.1-f15ad2d16f9be29f17cf3cf758fe7ba6
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
